@@ -4,16 +4,14 @@ Main interface for fis service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_fis import (
         Client,
         FISClient,
     )
 
-    session = boto3.Session()
-
-    client: FISClient = boto3.client("fis")
-    session_client: FISClient = session.client("fis")
+    session = Session()
+    client: FISClient = session.client("fis")
     ```
 """
 from .client import FISClient
