@@ -91,12 +91,12 @@ class FISClient(BaseClient):
         *,
         clientToken: str,
         description: str,
-        stopConditions: Sequence["CreateExperimentTemplateStopConditionInputTypeDef"],
-        actions: Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
+        stopConditions: Sequence[CreateExperimentTemplateStopConditionInputTypeDef],
+        actions: Mapping[str, CreateExperimentTemplateActionInputTypeDef],
         roleArn: str,
-        targets: Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"] = ...,
+        targets: Mapping[str, CreateExperimentTemplateTargetInputTypeDef] = ...,
         tags: Mapping[str, str] = ...,
-        logConfiguration: "CreateExperimentTemplateLogConfigurationInputTypeDef" = ...
+        logConfiguration: CreateExperimentTemplateLogConfigurationInputTypeDef = ...
     ) -> CreateExperimentTemplateResponseTypeDef:
         """
         Creates an experiment template.
@@ -248,11 +248,11 @@ class FISClient(BaseClient):
         *,
         id: str,
         description: str = ...,
-        stopConditions: Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"] = ...,
-        targets: Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"] = ...,
-        actions: Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"] = ...,
+        stopConditions: Sequence[UpdateExperimentTemplateStopConditionInputTypeDef] = ...,
+        targets: Mapping[str, UpdateExperimentTemplateTargetInputTypeDef] = ...,
+        actions: Mapping[str, UpdateExperimentTemplateActionInputItemTypeDef] = ...,
         roleArn: str = ...,
-        logConfiguration: "UpdateExperimentTemplateLogConfigurationInputTypeDef" = ...
+        logConfiguration: UpdateExperimentTemplateLogConfigurationInputTypeDef = ...
     ) -> UpdateExperimentTemplateResponseTypeDef:
         """
         Updates the specified experiment template.
